indexing

   description: "Base class that covers parts of the stat structure that%
   % are available with Windows and POSIX."

   author: "Berend de Boer"
   date: "$Date: 2001/12/27 $"
   revision: "$Revision: #1 $"


deferred class

   ABSTRACT_STATUS


inherit

   STDC_BASE


feature {NONE} -- creation

   make_stat is
      do
         create stat.allocate (abstract_stat_size)
      end


feature

   refresh is
         -- refresh the cached information
      deferred
      end


feature {NONE} -- state

   stat: STDC_BUFFER


feature -- stat members

   atime, access_time: INTEGER is
         -- Unix time of last access
      do
         Result := abstract_st_atime (stat.ptr)
      end

   ctime, change_time: INTEGER is
         -- Unix time of last status change, for example changing permission
         -- bits
      do
         Result := abstract_st_ctime (stat.ptr)
      end

   device_number: INTEGER is
         -- ID of device containing the file
         -- Windows: Drive number of the disk containing the file
      do
         Result := abstract_st_dev (stat.ptr)
      end

   is_character_special: BOOLEAN is
         -- True if character-special file
      do
         Result := abstract_s_ischr (abstract_st_mode (stat.ptr))
      end

   is_directory: BOOLEAN is
      do
         Result := abstract_s_isdir (abstract_st_mode (stat.ptr))
      end

   is_fifo: BOOLEAN is
      do
         Result := abstract_s_isfifo (abstract_st_mode (stat.ptr))
      end

   is_regular_file: BOOLEAN is
      do
         Result := abstract_s_isreg (abstract_st_mode (stat.ptr))
      end

   mtime, modification_time: INTEGER is
         -- Unix time of last data modification
      do
         Result := abstract_st_mtime (stat.ptr)
      end

   nlink, number_of_hard_links: INTEGER is
      do
         Result := abstract_st_nlink (stat.ptr)
      end

   size: INTEGER is
         -- size of file in bytes
      do
         Result := abstract_st_size (stat.ptr)
      end


feature -- direct access to the individual stat fields, not recommended

   unix_mode: INTEGER is
      do
         Result := abstract_st_mode (stat.ptr)
      end


feature {NONE} -- portable API functions

   abstract_st_atime (a_stat: POINTER): INTEGER is
         -- time of last access
      deferred
      end

   abstract_st_ctime (a_stat: POINTER): INTEGER is
         -- time of last status change
      deferred
      end

   abstract_st_dev (a_stat: POINTER): INTEGER is
         -- device number
      deferred
      end

   abstract_st_mode (a_stat: POINTER): INTEGER is
      deferred
      end

   abstract_st_mtime (a_stat: POINTER): INTEGER is
      -- time of last data modification
      deferred
      end

   abstract_st_nlink (a_stat: POINTER): INTEGER is
         -- number of hard links
      deferred
      end

   abstract_st_size (a_stat: POINTER): INTEGER is
         -- total size, in bytes
      deferred
      end

   abstract_stat_size: INTEGER is
         -- return size of struct stat
      deferred
      end


feature {NONE} -- test file type bits

   abstract_s_ischr (m: INTEGER): BOOLEAN is
      deferred
      end

   abstract_s_isdir (m: INTEGER): BOOLEAN is
      deferred
      end

   abstract_s_isfifo (m: INTEGER): BOOLEAN is
      deferred
      end

   abstract_s_isreg (m: INTEGER): BOOLEAN is
      deferred
      end


invariant

    valid_stat: stat /= Void


end -- class ABSTRACT_STATUS
