indexing

   description: "Test portable file system class."

   author: "Berend de Boer"
   date: "$Date: 2001/12/27 $"
   revision: "$Revision: #1 $"


class

   TEST_EPX_FILE_SYSTEM


inherit

   EPX_CURRENT_PROCESS

   EPX_FILE_SYSTEM


creation

   make


feature

   make is
      local
         file: STDC_TEXT_FILE
         stat: EPX_STATUS
         command: STDC_SHELL_COMMAND
         dir: ABSTRACT_DIRECTORY
         i: INTEGER
         name: STRING
         tmpfile: STDC_BINARY_FILE
         temp_status: EPX_STATUS
      do
         print ("Test EPX_FILE_SYSTEM%N")

         print ("The temporary directory: ")
         print (temporary_directory)
         print ("%N")

         test_directory

         create command.make ("/bin/ls -l *.tmp")

         name := "tmp.tmp"
         print ("Test accessibility of ")
         print (name)
         print (".%N")
         create tmpfile.create_read_write (name)
         tmpfile.close
         if is_existing (name) then
            print ("Is existing file.%N")
         else
            print ("!! Temporary file does not exist.%N")
         end
         if is_readable (name) then
            print ("Is real user ID readable file.%N")
         else
            print ("!! Temporary file is not real user ID readable.%N")
         end
         if is_writable (name) then
            print ("Is writable file.%N")
         else
            print ("!! Temporary file is not writable.%N")
         end
         if is_empty (name) then
            print ("Is empty file.%N")
         else
            print ("!! Temporary file is not empty.%N")
         end

         temp_status := status (name)
         print ("Last access time: ")
         print (temp_status.access_time)
         print ("%N")
         print ("Last change time: ")
         print (temp_status.change_time)
         print ("%N")
         print ("Last modification time: ")
         print (temp_status.modification_time)
         print ("%N")

         if temp_status.is_character_special then
            print ("!! Temporary file is a character device.%N")
         end
         if temp_status.is_directory then
            print ("!! Temporary file is a directory.%N")
         end
         if temp_status.is_fifo then
            print ("!! Temporary file is a fifo.%N")
         end
         if not temp_status.is_regular_file then
            print ("!! Temporary file isn't a regular file.%N")
         end

         remove_file (name)

         create tmpfile.create_read_write (name)
         tmpfile.close

         print ("Status info: %N")
         stat := status (name)
         print ("size: ")
         print (stat.size.out)
         print (".%N")

         remove_file (name)

         if not is_existing (name) then
            print ("Does not exist.%N")
         else
            print ("!! Temporary file still exists.%N")
         end

         print ("Test is_executable.%N")
         if is_executable ("/bin/sh") then
            print ("/bin/sh is executable file.%N")
         else
            print ("!! /bin/sh is not executable.%N")
         end

         print ("Create and remove a link.%N")
         create file.create_read_write ("file.tmp")
         file.close

         remove_file ("link.tmp")
         if is_existing ("link.tmp") then
            print ("!! link.tmp is not removed.%N")
         else
            print ("link.tmp is removed.%N")
         end
         remove_file ("file.tmp")
         if is_existing ("file.tmp") then
            print ("!! file.tmp is not removed.%N")
         else
            print ("file.tmp is removed.%N")
         end

         print ("Test directory reading.%N")
         from
            dir := browse_directory (".")
            dir.start
            i := 0
         until
            dir.exhausted
         loop
            i := i + 1
            print (dir.item)
            print ("%N")
            dir.forth
         end
         print ("Number of entries: ")
         print (i)
         print ("%N")

         print  ("End of test.%N")
      end


   test_directory is
      local
         dir: STRING
      do
         print ("Test directory functions%N")
         dir := getcwd
         chdir ("..")
         print ("Dir: ")
         print (getcwd)
         print (".%N")
         chdir (dir)
         print ("Dir: ")
         print (getcwd)
         print (".%N")
         if not equal(dir, getcwd) then
            print ("!! Directory is not the expected directory.%N")
         end
         mkdir ("abc")
         chdir ("abc")
         print ("Dir: ")
         print (getcwd)
         print (".%N")
         change_directory ("..")
         rename_to ("abc", "def")
         if not status("def").is_directory then
            print ("!! Temporary file is not a directory.%N")
         end
         rmdir ("def")
      end


end
