indexing

   description: "Test Standard C securiy class."

   author: "Berend de Boer"
   date: "$Date: 2001/12/27 $"
   revision: "$Revision: #1 $"


class 
   
   TEST_SECURITY
   
   
inherit
   
   POSIX_FILE_SYSTEM


creation
   
   make


feature
   
   make is
      do
         print ("testing Standard C security.%N")
         
         security.make_allow_sandbox
         security.make_allow_all

         test_cpu_time
         
         test_max_memory
         
         test_max_open_files
         
         test_exception_handling
         
         print ("End of Standard C secury test.%N")
      end
   

feature -- security tests
   
   test_cpu_time is
      local
         rescued: BOOLEAN
      do
         if not rescued then
            security.cpu.set_max_process_time (0)
            security.cpu.check_process_time
            print ("!! Max process time not detected.%N")
         end
      rescue
         rescued := True
         retry
      end
   
   test_max_memory is
      local
         rescued: BOOLEAN
         buf1, buf2: STDC_DYNAMIC_MEMORY
      do
         if not rescued then
            security.memory.set_max_allocated_memory (1024)
            create buf1.allocate (1024)
            create buf2.allocate (1024)
            print ("!! Max memory allocation not detected.%N")
         end
      rescue
         rescued := True
         security.memory.set_max_allocated_memory (65536)
         retry
      end
   
   test_max_open_files is
      local
         rescued: BOOLEAN
         file1, file2, file3: STDC_TEXT_FILE
      do
         if not rescued then
            security.files.set_max_open_files (5)
            create file1.create_write ("/tmp/file1")
            create file2.create_write ("/tmp/file2")
            create file3.create_write ("/tmp/file3")
            print ("!! Max open files not detected.%N")
         end
      rescue
         rescued := True
         file2.close
         file1.close
         retry
      end
   
   test_exception_handling is
      local
         file: STDC_BINARY_FILE
         fd: POSIX_FILE_DESCRIPTOR
         perm: POSIX_PERMISSIONS
      do
         security.error_handling.disable_exceptions
         create file.open_read ("does.not.exist")
         if file.errno.first_value = 0 then
            print ("!! first error not set.%N")
         end
         file.errno.clear_first
         create file.create_read_write ("/a/b/c/x/y/z/does.not.exist")
         if file.errno.first_value = 0 then
            print ("!! first error not set.%N")
         end
         file.errno.clear_first
         create fd.open_read ("does.not.exist")
         if file.errno.first_value = 0 then
            print ("!! first error not set.%N")
         end
         file.errno.clear_first
         change_directory ("does.not.exist")
         if file.errno.first_value = 0 then
            print ("!! first error not set.%N")
         end
         
         -- create a file and make it readonly
         touch ("/tmp/file.berend")
         perm := permissions ("/tmp/file.berend")
         perm.set_allow_owner_write (False)
         perm.apply
         create fd.create_write ("/tmp/file.berend")
         if fd.errno.first_value = 0 then
            print ("!! first error not set.%N")
         else
            create fd.open_read ("/tmp/file.berend")
         end
         fd.write_string ("1%N")
         fd.write_string ("2%N")
         if fd.errno.first_value = 0 then
            print ("!! first error not set.%N")
         else
            fd.errno.clear_first
         end
         fd.close
         
         security.error_handling.enable_exceptions
      end


end -- class TEST_SECURITY
